[KSS-checkins] r52420 - in kukit/kukit.js/branch/1.4: 3rd_party doc kukit

reebalazs at codespeak.net reebalazs at codespeak.net
Wed Mar 12 16:42:59 CET 2008


Author: reebalazs
Date: Wed Mar 12 16:42:59 2008
New Revision: 52420

Added:
   kukit/kukit.js/branch/1.4/3rd_party/base2-dom-fp-20070816.js
      - copied unchanged from r52418, kukit/kukit.js/trunk/3rd_party/base2-dom-fp-20070816.js
   kukit/kukit.js/branch/1.4/3rd_party/base2-dom-fp.js
      - copied unchanged from r52418, kukit/kukit.js/trunk/3rd_party/base2-dom-fp.js
Modified:
   kukit/kukit.js/branch/1.4/doc/HISTORY.txt
   kukit/kukit.js/branch/1.4/kukit/dom.js
Log:
Merge -r54718 from trunk: update base-dom-fp.js to fix running on FF3

Modified: kukit/kukit.js/branch/1.4/doc/HISTORY.txt
==============================================================================
--- kukit/kukit.js/branch/1.4/doc/HISTORY.txt	(original)
+++ kukit/kukit.js/branch/1.4/doc/HISTORY.txt	Wed Mar 12 16:42:59 2008
@@ -5,7 +5,11 @@
 kukit.js - 1.4dev Unreleased
     
     - ...
- 
+
+    - Updated base2-dom-fp.js with newest version.
+      This fixes breakage on FireFox 3.
+      [ree]
+
 kuki.js - 1.4-alpha1 Released 2008-03-09
 
     - refactor the value provider registry to use

Modified: kukit/kukit.js/branch/1.4/kukit/dom.js
==============================================================================
--- kukit/kukit.js/branch/1.4/kukit/dom.js	(original)
+++ kukit/kukit.js/branch/1.4/kukit/dom.js	Wed Mar 12 16:42:59 2008
@@ -86,19 +86,39 @@
 
 var _USE_BASE2 = (typeof(base2) != 'undefined');
 if (_USE_BASE2) {
-;;;kukit.log('Using cssQuery from base2.');
-    var _cssQuery = function(selector, inNodes) {
-        // global scope, always.
-        // This is very bad. However the binding makes sure that
-        // nodes once bound will never be bound again
-        // (also, noticed the following issue: cssQuery, when called
-        // on an element, does not check the element itself.)
-        var results = base2.DOM.Document.matchAll(document, selector);
-        var nodes = [];
-        for(var i = 0; i < results.length; i++) {
-            nodes.push(results.item(i));
-        }
-        return nodes;
+    // Base2 legacy version: matchAll has to be used
+    // Base2 recent version: querySelectorAll has to be used
+    var _USE_BASE2_LEGACY = (typeof(base2.DOM.Document.querySelectorAll) == 'undefined');
+    if (! _USE_BASE2_LEGACY) {
+;;;     kukit.log('Using cssQuery from base2.');
+        var _cssQuery = function(selector, inNodes) {
+            // global scope, always.
+            // This is very bad. However the binding makes sure that
+            // nodes once bound will never be bound again
+            // (also, noticed the following issue: cssQuery, when called
+            // on an element, does not check the element itself.)
+            var results = base2.DOM.Document.querySelectorAll(document, selector);
+            var nodes = [];
+            for(var i = 0; i < results.length; i++) {
+                nodes.push(results.item(i));
+            }
+            return nodes;
+        };
+    } else {
+;;;     kukit.log('Using cssQuery from base2. (Using legacy API document.matchAll)');
+        var _cssQuery = function(selector, inNodes) {
+            // global scope, always.
+            // This is very bad. However the binding makes sure that
+            // nodes once bound will never be bound again
+            // (also, noticed the following issue: cssQuery, when called
+            // on an element, does not check the element itself.)
+            var results = base2.DOM.Document.matchAll(document, selector);
+            var nodes = [];
+            for(var i = 0; i < results.length; i++) {
+                nodes.push(results.item(i));
+            }
+            return nodes;
+        };
     };
 } else {
 ;;;kukit.log('Using original cssQuery.');


More information about the Kukit-checkins mailing list